### Name: plot.kohonen
### Title: Plot kohonen object
### Aliases: plot.kohonen plot.somgrid plot.kohchanges plot.kohcounts
###   plot.kohcodes plot.kohprop plot.kohpred plot.heatkey plot.kohmapping
### Keywords: classif

### ** Examples

data(wines)
set.seed(7)

kohmap <- xyf(scale(wines), classvec2classmat(wine.classes),
              grid = somgrid(5, 5, "hexagonal"), rlen=100)
plot(kohmap, type="changes", main="plot of changes")
plot(kohmap, type="codes", main="codes plot")
plot(kohmap, type="counts", main="counts plot")
plot(kohmap, type="mapping", 
     labels=wine.classes, col=wine.classes,
     main="mapping plot")
plot(kohmap, type="mapping", 
     pchs=wine.classes, col=wine.classes,
     main="another mapping plot")

### Made-up labels :-)
plot(kohmap, type="prediction",
     labels=c("Chianti", "Barolo", "Montepulciano"),
     palette.name = rainbow,
     main="unit class prediction", cex=.8)

### Plot mean similarity of mapped objects to their unit codebook vector
mapping <- predict(kohmap, classif=kohmap$classif)
hits <- sort(unique(kohmap$classif))
similarities <- rep(NA, 25)
for (i in seq(along=hits))
  similarities[hits[i]] <- mean(mapping$distances[kohmap$classif == hits[i]])

plot(kohmap, type="property", property=similarities, main="property plot")



